vlib_plugin_register

Macro vlib_plugin_register 

vlib_plugin_register!() { /* proc-macro */ }
Register the plugin so that it can be loaded by VPP

Must only be done once per shared object, or linker errors will result.

Attributes

  • version: (required, string literal) The version string of the plugin. Must be at most 63 characters.
  • description: (optional, string literal) A description of the plugin.

Examples

vlib_plugin_register! {
    version: "1.0",
    description: "Example",
}