pub struct SimpleCounter { /* private fields */ }Expand description
Per-thread, per-object simple counters
Implementations
Sourceimpl SimpleCounter
impl SimpleCounter
Sourcepub fn allocate_index(
&self,
_vm: &BarrierHeldMainRef,
index: u32,
) -> SimpleCounterIndex<'_>
pub fn allocate_index( &self, _vm: &BarrierHeldMainRef, index: u32, ) -> SimpleCounterIndex<'_>
Allocate the given index for use, zeroing it in the process
This is similar to the VPP C API vlib_validate_simple_counter.
Note that no checks are performed to ensure that the index isn’t already in use, but it doesn’t result in unsoundness if the same value is allocated for an already-allocated and not dropped index.