SimpleCounterIndex

Struct SimpleCounterIndex 

pub struct SimpleCounterIndex<'counter> { /* private fields */ }
An allocated index for a SimpleCounter

Implementations

Source

impl<'counter> SimpleCounterIndex<'counter>

pub fn into_parts(self) -> (&'counter SimpleCounter, u32)

Decomposes a simple counter index into its component parts

pub unsafe fn from_parts(counter: &'counter SimpleCounter, index: u32) -> Self

Creates a SimpleCounterIndex from component parts

Safety
  • Must only be done from VPP worker threads or the main thread
  • index must be a valid (previously allocated) index for the counter
pub fn increment(&self, vm: &MainRef, count: u64)

Increment this thread’s per-thread counter

pub unsafe fn zero(&self)

Zero all threads’ per-thread counters

Safety
  • There must be no concurrent writers to this index. For example, worker threads without the barrier held.
pub fn get(&self, _vm: &MainRef) -> u64

Get the total count, summing for all threads