Module node

Module node 

VPP node abstractions

This module contains abstractions around VPP nodes, including node registration, node runtime data, frames, and error counters.

Structs

FrameRef
Reference to a VPP node frame
NodeFlags
Node flags
NodeRef
Reference to a VPP node
NodeRegistration
Registration information for a VPP node
NodeRuntimeRef
Reference to a VPP node runtime data

Constants

FRAME_DATA_ALIGN
Frame data alignment
FRAME_SIZE
Max number of vector elements to process at once per node
RUNTIME_DATA_ALIGN
Runtime data alignment

Traits

ErrorCounters
Trait for defining error counters of a VPP node
NextNodes
Trait for defining next nodes of a VPP node
Node
Trait for defining a VPP node
VectorBufferIndex
Trait for types that can be used as buffer indices in vector nodes