pub struct NodeFlags(/* private fields */);Expand description
Node flags
Implementations
Sourceimpl NodeFlags
impl NodeFlags
Sourcepub const FRAME_NO_FREE_AFTER_DISPATCH: Self
pub const FRAME_NO_FREE_AFTER_DISPATCH: Self
Don’t free the frame after dispatch - processing function keeps the frame
Sourcepub const IS_HANDOFF: Self
pub const IS_HANDOFF: Self
Internal node counts as handoff node for stats purposes
Sourcepub const SWITCH_FROM_INTERRUPT_TO_POLLING_MODE: Self
pub const SWITCH_FROM_INTERRUPT_TO_POLLING_MODE: Self
The node is in the process of switching from interrupt to polling mode
Sourcepub const SWITCH_FROM_POLLING_TO_INTERRUPT_MODE: Self
pub const SWITCH_FROM_POLLING_TO_INTERRUPT_MODE: Self
The node is in the process of switching from polling to interrupt mode
Sourcepub const TRACE_SUPPORTED: Self
pub const TRACE_SUPPORTED: Self
The node can initiate a per-node packet trace
Sourcepub const ADAPTIVE_MODE: Self
pub const ADAPTIVE_MODE: Self
The node supports automatic switching between interrupt and polling mode
Sourcepub const ALLOW_LAZY_NEXT_NODES: Self
pub const ALLOW_LAZY_NEXT_NODES: Self
Allows the node registration to refer to a next node that doesn’t exist at registration time
Sourceimpl NodeFlags
impl NodeFlags
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl NodeFlags
impl NodeFlags
Sourcepub const fn iter(&self) -> Iter<NodeFlags>
pub const fn iter(&self) -> Iter<NodeFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<NodeFlags>
pub const fn iter_names(&self) -> IterNames<NodeFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.