Module node_generic

Module node_generic 

Generic node implementations

This module contains generic implementations of VPP nodes following set patterns that can be reused across different plugins.

Enums

FeatureNextNode
Next node to send a buffer to from a generic node implementation

Traits

GenericFeatureNodeX1
Trait for generic node implementations processing one buffer at a time in a feature arc
GenericFeatureNodeX4
Trait for generic node implementations processing one buffer at a time in a feature arc

Functions

generic_feature_node_x1
Generic implementation of a VPP node processing one buffer at a time in a feature arc
generic_feature_node_x4
Generic implementation of a VPP node processing four buffers at a time in a feature arc