pub enum FeatureNextNode<NextNode> {
DefinedNode(NextNode),
NextFeature,
}Expand description
Next node to send a buffer to from a generic node implementation
Variants
DefinedNode(NextNode)
A specific next node defined by the generic node implementation
NextFeature
The next feature in the feature arc