pub trait GenericFeatureNodeX1<N: Node> {
// Required method
unsafe fn map_buffer_to_next(
&self,
vm: &MainRef,
node: &mut NodeRuntimeRef<N>,
b0: &mut BufferRef<N::FeatureData>,
) -> FeatureNextNode<N::NextNodes>;
}Expand description
Trait for generic node implementations processing one buffer at a time in a feature arc
Required Methods
Sourceunsafe fn map_buffer_to_next(
&self,
vm: &MainRef,
node: &mut NodeRuntimeRef<N>,
b0: &mut BufferRef<N::FeatureData>,
) -> FeatureNextNode<N::NextNodes>
unsafe fn map_buffer_to_next( &self, vm: &MainRef, node: &mut NodeRuntimeRef<N>, b0: &mut BufferRef<N::FeatureData>, ) -> FeatureNextNode<N::NextNodes>
Processing a buffer and determining the next node to send it to
Safety
The safety preconditions vary depending on the specific implementation.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".