Module core

Module core 

Available on crate feature process-node only.
Core infrastructure for VPP process nodes

This module provides the ProcessNode trait and core infrastructure for running async/await coroutines within VPP process nodes.

Structs

Elapsed
Errors returned by Timeout.
LocalFutureObj
A custom trait object for polling futures, roughly akin to Box<dyn Future<Output = T> + 'a>.
ProcessAsyncContext
Async context for running a future within a VPP process node.
ProcessNodeRegistration
Registration information for a VPP process node
Sleep
Future returned by sleep()
Timeout
Future returned by timeout.

Traits

ProcessNode
Trait for defining a VPP process (async) node

Functions

sleep
Waits until duration has elapsed.
timeout
Apply a timeout to the given future