pub struct ProcessAsyncContext<'a> { /* private fields */ }Available on crate feature
process-node only.Expand description
Async context for running a future within a VPP process node.
This struct holds the state needed to poll a async future from the VPP process node loop, including a timer wheel for async operations.
Implementations
Sourceimpl<'a> ProcessAsyncContext<'a>
impl<'a> ProcessAsyncContext<'a>
Sourcepub fn new<N>(
vm: &'a mut MainRef,
node: &NodeRuntimeRef<N>,
future: LocalFutureObj<'a, ()>,
) -> Self
pub fn new<N>( vm: &'a mut MainRef, node: &NodeRuntimeRef<N>, future: LocalFutureObj<'a, ()>, ) -> Self
Create a new async context for the given future.