ProcessNodeRegistration

Struct ProcessNodeRegistration 

pub struct ProcessNodeRegistration<N: ProcessNode, const N_NEXT_NODES: usize> { /* private fields */ }
Available on crate feature process-node only.
Registration information for a VPP process node

Used for registering and unregistering process nodes with VPP.

This is typically created automatically using the vpp_plugin_macros::vlib_process_node macro.

Implementations

Source

impl<N: ProcessNode, const N_NEXT_NODES: usize> ProcessNodeRegistration<N, N_NEXT_NODES>

pub const fn new( registration: _vlib_node_registration<[*mut c_char; N_NEXT_NODES]>, ) -> Self

Creates a new ProcessNodeRegistration from the given registration data

pub unsafe fn register(&'static self)

Registers the node with VPP

Safety
  • Must be called only once for this node registration.
  • Must be called from a constructor function that is invoked before VPP initialises.
  • The following pointers in the registration data must be valid:
    • name (must be a valid, nul-terminated string)
    • function (must point to a valid node function)
    • error_descriptions (must point to an array of n_errors valid vlib_error_desc_t entries)
    • next_nodes (each entry must be a valid nul-terminated string and length must be at least n_next_nodes)
  • Other pointers in the registration data must be either valid or null as appropriate.
  • vector_size, scalar_size, and aux_size must match the sizes of the corresponding types in N.
  • n_errors must match the discriminants in N::Errors
  • n_next_nodes must match the discriminants in N::NextNodes
pub unsafe fn unregister(&self)

Unregisters the node from VPP

Safety
  • Must be called only once for this node registration.
  • Must be called from a destructor function that is invoked after VPP uninitialises.
  • The node must have been previously registered with VPP using Self::register.
pub unsafe fn node_runtime_from_ptr<'a>( &self, ptr: *mut vlib_node_runtime_t, ) -> &'a mut NodeRuntimeRef<N>

Creates a &mut NodeRuntimeRef directly from a pointer

This is a convenience method that calls NodeRuntimeRef::from_ptr_mut, for code that has an instance of NodeRegistration, but doesn’t know the name of the type for the node. As such, self isn’t used, it’s just taken so that the generic types are known.

Safety