Module mpsc

Module mpsc 

Available on crate feature process-node only.
Multi-producer, single-consumer channel for sending data into asynchronous tasks

Structs

Receiver
Receiver for a single consumer side of an MPSC channel.
ReceiverFuture
Future for receiver for a single consumer side of an MPSC channel.
Sender
A multiple-producer, single-consumer channel for async process events.

Functions

channel
Create an unbounded multi-producer single-consumer channel.