registration_scope

Function registration_scope 

pub fn registration_scope<F, T>(f: F) -> T
where F: for<'scope> FnOnce(&'scope RegistrationScope<'scope>) -> T,
Execute a closure with a temporary RegistrationScope.

Used to ensure any &mut Registration borrows that are obtained are tied to the lifetime of the closure and cannot accidentally escape.