UnalignedF64

Struct UnalignedF64 

pub struct UnalignedF64(/* private fields */);
A f64 that has an alignment requirement of 1 byte, i.e. is unaligned

This is useful in packed structures and slices of data contained in variable-length arrays in VPP messages.

Layout

UnalignedF64 is guaranteed to have the same layout and bit validity as f64.

They are also guaranteed to have the same size.

Implementations

Source

impl UnalignedF64

pub const fn new(value: f64) -> Self

Creates a f64 that has an alignment requirement of 1 byte, i.e. is unaligned.

pub const fn get(self) -> f64

Returns the contained value as a primitive type.

pub fn swap_bytes(self) -> Self

Reverses the byte order of the float.

Examples
let n = UnalignedF64::new(1.0f64);
let m = n.swap_bytes();
// The result depends on the endianness of the target
pub fn to_be(self) -> Self

Converts self to big endian from the target’s endianness.

On big endian this is a no-op. On little endian the bytes are swapped.

Examples
let n = UnalignedF64::new(1.0f64);

if cfg!(target_endian = "big") {
    assert_eq!(n.to_be(), n)
} else {
    assert_eq!(n.to_be(), n.swap_bytes())
}
pub fn from_be(x: Self) -> Self

Converts a float from big endian to the target’s endianness.

On big endian this is a no-op. On little endian the bytes are swapped.

Examples
let n = UnalignedF64::new(1.0f64);

if cfg!(target_endian = "big") {
    assert_eq!(UnalignedF64::from_be(n), n)
} else {
    assert_eq!(UnalignedF64::from_be(n), n.swap_bytes())
}