pub struct UnalignedI64(/* private fields */);Expand description
A i64 that has an alignment requirement of 1 byte, i.e. is unaligned
This is useful in packed structures and slices of data contained in variable-length arrays in VPP messages.
Layout
UnalignedI64 is guaranteed to have the same layout and bit validity as i64.
They are also guaranteed to have the same size.
Implementations
Sourceimpl UnalignedI64
impl UnalignedI64
Sourcepub const fn new(value: i64) -> Self
pub const fn new(value: i64) -> Self
Creates a i64 that has an alignment requirement of 1 byte, i.e. is unaligned.
Sourcepub const fn swap_bytes(self) -> Self
pub const fn swap_bytes(self) -> Self
Reverses the byte order of the integer.
Examples
let n = UnalignedI64::new(0x1234567890123456i64);
let m = n.swap_bytes();
assert_eq!(m, 0x5634129078563412);Sourcepub const fn to_be(self) -> Self
pub const fn to_be(self) -> Self
Converts self to big endian from the target’s endianness.
On big endian this is a no-op. On little endian the bytes are swapped.
Examples
let n = UnalignedI64::new(0x1Ai64);
if cfg!(target_endian = "big") {
assert_eq!(n.to_be(), n)
} else {
assert_eq!(n.to_be(), n.swap_bytes())
}Sourcepub const fn from_be(x: Self) -> Self
pub const fn from_be(x: Self) -> Self
Converts an integer from big endian to the target’s endianness.
On big endian this is a no-op. On little endian the bytes are swapped.
Examples
let n = UnalignedI64::new(0x1Ai64);
if cfg!(target_endian = "big") {
assert_eq!(UnalignedI64::from_be(n), n)
} else {
assert_eq!(UnalignedI64::from_be(n), n.swap_bytes())
}Trait Implementations
Sourceimpl Add<i64> for UnalignedI64
impl Add<i64> for UnalignedI64
Sourceimpl Add for UnalignedI64
impl Add for UnalignedI64
Sourceimpl Clone for UnalignedI64
impl Clone for UnalignedI64
Sourcefn clone(&self) -> UnalignedI64
fn clone(&self) -> UnalignedI64
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnalignedI64
impl Debug for UnalignedI64
Sourceimpl Display for UnalignedI64
impl Display for UnalignedI64
Sourceimpl Div<i64> for UnalignedI64
impl Div<i64> for UnalignedI64
Sourceimpl Div for UnalignedI64
impl Div for UnalignedI64
Sourceimpl From<UnalignedI64> for i64
impl From<UnalignedI64> for i64
Sourcefn from(value: UnalignedI64) -> Self
fn from(value: UnalignedI64) -> Self
Converts to this type from the input type.
Sourceimpl From<i64> for UnalignedI64
impl From<i64> for UnalignedI64
Sourceimpl FromStr for UnalignedI64
impl FromStr for UnalignedI64
Sourceimpl Hash for UnalignedI64
impl Hash for UnalignedI64
Sourceimpl Mul<i64> for UnalignedI64
impl Mul<i64> for UnalignedI64
Sourceimpl Mul for UnalignedI64
impl Mul for UnalignedI64
Sourceimpl Ord for UnalignedI64
impl Ord for UnalignedI64
Sourcefn cmp(&self, other: &UnalignedI64) -> Ordering
fn cmp(&self, other: &UnalignedI64) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq<i64> for UnalignedI64
impl PartialEq<i64> for UnalignedI64
Sourceimpl PartialEq for UnalignedI64
impl PartialEq for UnalignedI64
Sourceimpl PartialOrd<i64> for UnalignedI64
impl PartialOrd<i64> for UnalignedI64
Sourceimpl PartialOrd for UnalignedI64
impl PartialOrd for UnalignedI64
Sourceimpl Sub<i64> for UnalignedI64
impl Sub<i64> for UnalignedI64
Sourceimpl Sub for UnalignedI64
impl Sub for UnalignedI64
impl Copy for UnalignedI64
impl Eq for UnalignedI64
impl StructuralPartialEq for UnalignedI64