UnalignedU64

Struct UnalignedU64 

pub struct UnalignedU64(/* private fields */);
A u64 that has an alignment requirement of 1 byte, i.e. is unaligned

This is useful in packed structures and slices of data contained in variable-length arrays in VPP messages.

Layout

UnalignedU64 is guaranteed to have the same layout and bit validity as u64.

They are also guaranteed to have the same size.

Implementations

Source

impl UnalignedU64

pub const fn new(value: u64) -> Self

Creates a u64 that has an alignment requirement of 1 byte, i.e. is unaligned.

pub const fn get(self) -> u64

Returns the contained value as a primitive type.

pub const fn swap_bytes(self) -> Self

Reverses the byte order of the integer.

Examples
let n = UnalignedU64::new(0x1234567890123456u64);
let m = n.swap_bytes();

assert_eq!(m, 0x5634129078563412);
pub const fn to_be(self) -> Self

Converts self to big endian from the target’s endianness.

On big endian this is a no-op. On little endian the bytes are swapped.

Examples
let n = UnalignedU64::new(0x1Au64);

if cfg!(target_endian = "big") {
    assert_eq!(n.to_be(), n)
} else {
    assert_eq!(n.to_be(), n.swap_bytes())
}
pub const fn from_be(x: Self) -> Self

Converts an integer from big endian to the target’s endianness.

On big endian this is a no-op. On little endian the bytes are swapped.

Examples
let n = UnalignedU64::new(0x1Au64);

if cfg!(target_endian = "big") {
    assert_eq!(UnalignedU64::from_be(n), n)
} else {
    assert_eq!(UnalignedU64::from_be(n), n.swap_bytes())
}