Message

Struct Message 

pub struct Message<T: ?Sized> { /* private fields */ }
An owned VPP message buffer containing a T.

The message can be sent to a client using Registration::send_message.

Important invariant:

  • T must have an alignment of 1 (e.g. by #[repr(packed)])

Implementations

Source

impl<T> Message<T>

pub fn new(value: T) -> Self

Allocate a VPP message and initialise it by copying value into the newly-allocated buffer.

Panics

Panics if align_of::<T>() != 1 because the VPP API message allocator does not provide alignment guarantees; generated message structs are expected to be packed.

pub fn new_uninit() -> Message<MaybeUninit<T>>

Allocate an uninitialised VPP message buffer for T.

This returns a Message<MaybeUninit<T>>. Use Self::write or Self::assume_init after manually initialising the contents.

Panics

Panics if align_of::<T>() != 1 for the same reason as new.

Source

impl Message<u8>

pub fn new_bytes(nbytes: u32) -> Message<u8>

Allocate a VPP message buffer nbytes of u8s initialised to 0.

Source

impl<T: ?Sized> Message<T>

pub fn into_raw(m: Self) -> *mut T

Consume the Message and return the raw pointer to the underlying buffer

The returned pointer becomes the caller’s responsibility. The Message destructor will not run for m and the underlying buffer will not be freed by Rust; callers must ensure the buffer is eventually freed (for example by passing it to VPP or calling vl_msg_api_free).

Not a method on Message to avoid clashing with application methods of the same name on the underlying type.

Source

impl<T> Message<MaybeUninit<T>>

pub unsafe fn assume_init(self) -> Message<T>

Convert a Message<MaybeUninit<T>> into a Message<T> without performing any initialisation checks

Safety

The caller must ensure that the underlying buffer is fully initialised for T. If the memory is not properly initialised, using the resulting Message<T> is undefined behaviour.

pub fn write(self, value: T) -> Message<T>

Initialise the previously-uninitialised buffer with value and return the initialised Message<T>