Module vppinfra

Module vppinfra 

VPP core library

This module contains abstractions around VPP’s core library, vppinfra, including vectors and utilities.

Re-exports

pub use vec::Vec;
pub use vec::VecRef;

Modules

cache
Cache utilities and definitions
error
VPP error type abstractions
unformat
Generalised string parsing
vec
Dynamically resizable arrays

Functions

cold_path
Hints to the compiler that the given code path is cold, i.e., unlikely to be executed.
likely
Hints to the compiler that the given boolean expression is likely to be true
unlikely
Hints to the compiler that the given boolean expression is unlikely to be true