Module error

Module error 

VPP error type abstractions

This module provides abstractions around VPP’s error handling, including an error stack type that can represent a chain of errors similar to Rust’s std::error::Error.

Structs

Error
A single VPP error
ErrorStack
A stack of VPP errors