ErrorStack

Struct ErrorStack 

pub struct ErrorStack(/* private fields */);
A stack of VPP errors

This type represents a stack of VPP errors, similar to Rust’s std::error::Error. It typically corresponds to a clib_error_t * returned by VPP APIs.

Implementations

Source

impl ErrorStack

pub unsafe fn from_raw(ptr: *mut clib_error_t) -> Self

Creates an ErrorStack directly from a pointer

Safety
  • The pointer must be valid and point to a VPP vector of type clib_error_t.
  • The pointer must stay valid and the contents must not be mutated for the duration of the lifetime of the returned object.
pub fn into_raw(self) -> *mut clib_error_t

Consumes the error stack and returns a raw pointer

After calling this method, the caller is responsible for managing the memory of the vector of errors.

pub fn new<E: StdError + Send + Sync + 'static>(e: E) -> Self

Creates a new error stack from a standard error

The error message is taken from the Display version of the error.

Panics

Panics if the error message contains nul characters.

pub fn msg<M>(message: M) -> Self
where M: Display + Send + Sync + 'static,

Creates a new error stack from a message

Panics

Panics if the message contains nul characters.

pub fn context<C>(self, context: C) -> Self
where C: Display + Send + Sync + 'static,

Adds context to the error stack

Panics

Panics if the context message contains nul characters.

pub fn errors(&self) -> &[Error]

Returns the errors in the stack.