Module buffer

Module buffer 

vlib buffer abstraction

This module contains abstractions around VPP’s vlib_buffer_t structure. It provides safe access to buffer fields and operations. It also includes buffer allocation and deallocation functions. The goal is to provide a safe and ergonomic interface for working with VPP buffers.

Structs

BufferAllocError
Buffer allocation error
BufferFlags
vlib buffer flags
BufferIndex
VPP buffer index
BufferRef
Reference to a VPP buffer
BufferWithContext
Owned buffer (with context)

Functions

vlib_buffer_flag_user
Construct a user buffer flag