vlib buffer abstraction
This module contains abstractions around VPP’s vlib_buffer_t structure.
It provides safe access to buffer fields and operations.
It also includes buffer allocation and deallocation functions.
The goal is to provide a safe and ergonomic interface for working with VPP buffers.
Structs
- Buffer
Alloc Error - Buffer allocation error
- Buffer
Flags - vlib buffer flags
- Buffer
Index - VPP buffer index
- Buffer
Ref - Reference to a VPP buffer
- Buffer
With Context - Owned buffer (with context)
Functions
- vlib_
buffer_ flag_ user - Construct a user buffer flag