pub trait VectorBufferIndex: Send + Copy {
// Required method
fn as_u32_slice(slice: &[Self]) -> &[u32];
}Expand description
Trait for types that can be used as buffer indices in vector nodes
Required Methods
Sourcefn as_u32_slice(slice: &[Self]) -> &[u32]
fn as_u32_slice(slice: &[Self]) -> &[u32]
Converts a slice of Self to a slice of u32
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.