Generic node implementations
This module contains generic implementations of VPP nodes following set patterns that can be reused across different plugins.
Enums
- Feature
Next Node - Next node to send a buffer to from a generic node implementation
Traits
- Generic
Feature Node X1 - Trait for generic node implementations processing one buffer at a time in a feature arc
- Generic
Feature Node X4 - Trait for generic node implementations processing one buffer at a time in a feature arc
Functions
- generic_
feature_ ⚠node_ x1 - Generic implementation of a VPP node processing one buffer at a time in a feature arc
- generic_
feature_ ⚠node_ x4 - Generic implementation of a VPP node processing four buffers at a time in a feature arc