pub unsafe fn generic_feature_node_x1<GenericNode, N, FeatureData>(
vm: &MainRef,
node: &mut NodeRuntimeRef<N>,
frame: &mut FrameRef<N>,
generic_node_impl: GenericNode,
) -> u16where
N: Node<Vector = BufferIndex, Scalar = (), Aux = (), FeatureData = FeatureData>,
GenericNode: GenericFeatureNodeX1<N>,
FeatureData: Copy,Expand description
Generic implementation of a VPP node processing one buffer at a time in a feature arc
Safety
- The preconditions of the
GenericFeatureNodeX1::map_buffer_to_nextmethod must be upheld. - Nodes with this node as a next node must send valid buffer indices in the Vector data.
- This mode must be invoked as part of a feature arc.
- All of the next nodes of this node must have a
Vectortype ofBufferIndex,Scalarof()andAuxof()(or their C equivalents).