pub struct UnalignedF64(/* private fields */);Expand description
A f64 that has an alignment requirement of 1 byte, i.e. is unaligned
This is useful in packed structures and slices of data contained in variable-length arrays in VPP messages.
Layout
UnalignedF64 is guaranteed to have the same layout and bit validity as f64.
They are also guaranteed to have the same size.
Implementations
Sourceimpl UnalignedF64
impl UnalignedF64
Sourcepub const fn new(value: f64) -> Self
pub const fn new(value: f64) -> Self
Creates a f64 that has an alignment requirement of 1 byte, i.e. is unaligned.
Sourcepub fn swap_bytes(self) -> Self
pub fn swap_bytes(self) -> Self
Reverses the byte order of the float.
Examples
let n = UnalignedF64::new(1.0f64);
let m = n.swap_bytes();
// The result depends on the endianness of the targetSourcepub fn to_be(self) -> Self
pub fn to_be(self) -> Self
Converts self to big endian from the target’s endianness.
On big endian this is a no-op. On little endian the bytes are swapped.
Examples
let n = UnalignedF64::new(1.0f64);
if cfg!(target_endian = "big") {
assert_eq!(n.to_be(), n)
} else {
assert_eq!(n.to_be(), n.swap_bytes())
}Sourcepub fn from_be(x: Self) -> Self
pub fn from_be(x: Self) -> Self
Converts a float from big endian to the target’s endianness.
On big endian this is a no-op. On little endian the bytes are swapped.
Examples
let n = UnalignedF64::new(1.0f64);
if cfg!(target_endian = "big") {
assert_eq!(UnalignedF64::from_be(n), n)
} else {
assert_eq!(UnalignedF64::from_be(n), n.swap_bytes())
}Trait Implementations
Sourceimpl Add<f64> for UnalignedF64
impl Add<f64> for UnalignedF64
Sourceimpl Add for UnalignedF64
impl Add for UnalignedF64
Sourceimpl Clone for UnalignedF64
impl Clone for UnalignedF64
Sourcefn clone(&self) -> UnalignedF64
fn clone(&self) -> UnalignedF64
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnalignedF64
impl Debug for UnalignedF64
Sourceimpl Display for UnalignedF64
impl Display for UnalignedF64
Sourceimpl Div<f64> for UnalignedF64
impl Div<f64> for UnalignedF64
Sourceimpl Div for UnalignedF64
impl Div for UnalignedF64
Sourceimpl From<UnalignedF64> for f64
impl From<UnalignedF64> for f64
Sourcefn from(value: UnalignedF64) -> Self
fn from(value: UnalignedF64) -> Self
Converts to this type from the input type.
Sourceimpl From<f64> for UnalignedF64
impl From<f64> for UnalignedF64
Sourceimpl FromStr for UnalignedF64
impl FromStr for UnalignedF64
Sourceimpl Mul<f64> for UnalignedF64
impl Mul<f64> for UnalignedF64
Sourceimpl Mul for UnalignedF64
impl Mul for UnalignedF64
Sourceimpl PartialEq<f64> for UnalignedF64
impl PartialEq<f64> for UnalignedF64
Sourceimpl PartialEq for UnalignedF64
impl PartialEq for UnalignedF64
Sourceimpl PartialOrd<f64> for UnalignedF64
impl PartialOrd<f64> for UnalignedF64
Sourceimpl PartialOrd for UnalignedF64
impl PartialOrd for UnalignedF64
Sourceimpl Sub<f64> for UnalignedF64
impl Sub<f64> for UnalignedF64
Sourceimpl Sub for UnalignedF64
impl Sub for UnalignedF64
impl Copy for UnalignedF64
impl StructuralPartialEq for UnalignedF64