Stream

Struct Stream 

pub struct Stream<'scope, T> { /* private fields */ }
A stream for sending messages to a registration

Implementations

Source

impl<'scope, T> Stream<'scope, T>

pub fn new(registration: &'scope mut Registration) -> Self

Creates a new stream from a mutable reference to a registration.

pub fn send_message_ne(&mut self, message: Message<T>)

Sends a network-endian (big-endian) message to the registration

Since the message is in network order, then it is sent without performing an endian swap.

pub fn into_inner(self) -> &'scope mut Registration

Consumes the stream and returns the underlying registration reference.

Source

impl<'scope, T: EndianSwap> Stream<'scope, T>

pub unsafe fn send_message(&mut self, message: Message<T>)

Sends a message to the registration after performing endian swap to network order.

Safety

The caller must ensure that if messages contains a variable length array that elements indexed from 0 up to the contents of the length field are initialised and contained within the memory allocated for the object.