pub trait EndianSwap {
// Required method
fn endian_swap(&mut self, to_net: bool);
}Expand description
Trait used by generated message types that require endian conversions.
Implementations should swap fields between host and network byte order.
Required Methods
Sourcefn endian_swap(&mut self, to_net: bool)
fn endian_swap(&mut self, to_net: bool)
Swap the endianness of the message in-place.
to_net == true indicates conversion from host to network order.