BufferRef

Struct BufferRef 

pub struct BufferRef(/* private fields */);
Reference to a VNET buffer

A &mut BufferRef is equivalent to a vnet_buffer_opaque_t * in C (a *vnet_buffer_opaque_t in Rust).

Implementations

Source

impl BufferRef

pub unsafe fn from_ptr<'a>(ptr: *const vnet_buffer_opaque_t) -> &'a BufferRef

Create a &BufferRef from a raw pointer

Safety
  • The pointer must be a valid and properly initialised vlib_buffer_t.
  • The pointer must stay valid and the contents must not be mutated for the duration of the lifetime of the returned object.
pub unsafe fn from_ptr_mut<'a>( ptr: *mut vnet_buffer_opaque_t, ) -> &'a mut BufferRef

Create a &mut BufferRef from a raw pointer

Safety
  • The pointer must be a valid and properly initialised vlib_buffer_t.
  • The pointer must stay valid and the contents must not be mutated for the duration of the lifetime of the returned object.
pub fn as_ptr(&self) -> *mut vnet_buffer_opaque_t

Returns the raw pointer to the underlying vnet_buffer_opaque_t

pub fn feature_arc_index(&self) -> u8

Returns the index of the feature arc that the buffer is being processed from